@@ -491,7 +491,7 @@ sourceview_reload_save_markers (Sourceview* sv)
 
 		sscanf (gtk_text_mark_get_name (GTK_TEXT_MARK (source_mark)),
 		        MARK_NAME "%d", &reload->handle);
-		sv->priv->tooltip = g_strdup (g_object_get_data (G_OBJECT (source_mark),
+		reload->tooltip = g_strdup (g_object_get_data (G_OBJECT (source_mark),
 														 MARKER_TOOLTIP_DATA));
 			
 		sv->priv->reload_marks = g_slist_append (sv->priv->reload_marks, reload);
@@ -992,9 +992,13 @@ ifile_open (IAnjutaFile* ifile, GFile* file, GError** e)
 
 	/* Hold a reference here to avoid a destroyed editor */
 	g_object_ref(G_OBJECT(sv));
+
+	gtk_source_buffer_begin_not_undoable_action (GTK_SOURCE_BUFFER (sv->priv->document));
 	gtk_text_buffer_set_text (GTK_TEXT_BUFFER(sv->priv->document),
 							  "",
 							  0);
+	gtk_source_buffer_end_not_undoable_action (GTK_SOURCE_BUFFER (sv->priv->document));
+
 	gtk_text_view_set_editable (GTK_TEXT_VIEW (sv->priv->view),
 								FALSE);
 	sv->priv->loading = TRUE;
